Sites using Singing&Dancing
===========================

.. note::

   This list is really incomplete because previously these entries were
   maintained on google groups until they changed their functionality and all
   maintained entries got lost.

Please feel free to add you site. You can add version in brackets if wanted and
add some more text using github markup syntax.

- http://intercom.carimac.com  (0.8.12)

- http://nadrogach.pap.pl (0.7.1)
  is an informational service devoted to
  motorization, road trafiic and road safety. The service is edited by
  polish press agency.

- http://kulturzeitschrift.at using S&D for automated newsletter
  creation. People subscribe to topics they are interested in and
  receive newsletters only containing that information.

